@@ -11,7 +11,7 @@ PICTURE_FORMATS = {
 TEMP_FOLDER = gettempdir()
 LOCAL_INTEGRATED_FOLDER = 'C:/Users/Public/Documents/Scala/LocalIntegratedContent'
 
-APIS = ['', 'BBC', 'NS', 'NU', 'TRAFFIC', 'INSTAGRAM', 'WEATHER', 'AMBER_ALERT']
+APIS = ['', 'BBC', 'NS', 'NU', 'TRAFFIC', 'INSTAGRAM', 'WEATHER', 'AMBER_ALERT', 'AMS_AIRPORT']
 
 VIDEO_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'video']
 IMG_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'image']
