@@ -7,8 +7,8 @@ def lst_dict_to_root(json):
 
     for elem in json:
         item = ET.SubElement(root, 'item')
-        for (key, value) in elem:
-            ET.SubElement(item, key).text = value
+        for (key, value) in elem.items():
+            ET.SubElement(item, key).text = str(value)
     
     return root
 
